@@ -7,12 +7,13 @@ use Exporter::Tiny;
 use IPC::Open2;
 use IO::Select;
 use File::Which;
+use Encode qw(encode decode);
 use Carp;
 
 use constant BLKSIZE => 1024;
 
 our
-	$VERSION = '0.09';
+	$VERSION = '0.10';
 
 our @ISA = qw(Exporter::Tiny);
 
@@ -55,6 +56,7 @@ sub _get_shell {
 	my $shell;
 	$shell->{shell} = \@cmd;
 	$shell->{debug} = $args{debug};
+	$shell->{encoding} = $args{encoding} // 'UTF-8';
 	return $shell;
 }
 
@@ -72,7 +74,7 @@ sub run {
 	shift;
 
 	# cmd input
-	my $input = shift;
+	my $input = encode($self->{encoding}, shift);
 	open my $inh, '<', \$input or croak "cannot open input data";
 	print STDERR "have input data\n" if $self->{debug} && $input;
 
@@ -124,7 +126,7 @@ sub run {
 			}
 			print STDERR "read $bytes bytes from cmd\n"
 				if $self->{debug} && $bytes;
-			$output .= $data;
+			$output .= decode($self->{encoding}, $data);
 
 			# finish on eof from cmd
 			if (! $bytes) {
@@ -491,6 +493,11 @@ Use I<export> as the name of the exported subroutine.
 
 Provide debugging output to C<STDERR> if I<debug> has a true value.
 
+=item encoding => I<encoding>
+
+Specify encoding for input and output data.
+Defaults to C<UTF-8>.
+
 =back
 
 =back
